@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 
-import subprocess
+from itertools import repeat
 from optparse import make_option
 
 from django.core.management.base import NoArgsCommand, BaseCommand
@@ -33,32 +33,46 @@ class Command(HerokuCommandMixin, NoArgsCommand):
             help = "If specified, then running database migrations will be skipped.",
         ),
     ) + HerokuCommandMixin.option_list
-    
+
     def handle(self, **kwargs):
         self.app = kwargs["app"]
+        # Build app code.
+        if kwargs["deploy_app"]:
+            self.stdout.write("Building app...\n")
+            # Install the anvil plugin.
+            self.heroku("plugins:install", "https://github.com/ddollar/heroku-anvil")
+            # Build the slug.
+            app_slug = self.heroku("build", pipeline=True, _out=None)
         # Deploy static asssets.
         if kwargs["deploy_staticfiles"]:
             self.stdout.write("Deploying static files...\n")
             call_command("collectstatic", interactive=False)
+        # Store a snapshot of the running processes.
+        heroku_ps = self.heroku.ps()
         # Enter maintenance mode, if required.
         if kwargs["deploy_database"]:
-            self.call_heroku_command("maintenance:on")
+            self.heroku("maintenance:on")
+            # Turn off all dynos.
+            if heroku_ps:
+                self.heroku.scale(**dict(zip(heroku_ps.keys(), repeat(0))))
         # Deploy app code.
         if kwargs["deploy_app"]:
-            self.stdout.write("Pushing latest version of app to Heroku...\n")
-            # Load app info.
-            app_info = self.call_heroku_shell_params_command("apps:info")
-            # Look up local branch.
-            (current_branch, _) = subprocess.Popen(("git rev-parse --abbrev-ref HEAD",), shell=True, stdout=subprocess.PIPE).communicate()
-            # Run the git push.
-            subprocess.call(("git", "push", app_info.get("git_url", "heroku"), "{current_branch}:master".format(current_branch=current_branch.strip()),))
+            self.stdout.write("Deploying latest version of app to Heroku...\n")
+            # Deploy app.
+            self.heroku("release", app_slug)
         # Deploy migrations.
         if kwargs["deploy_database"]:
             self.stdout.write("Deploying database...\n")
-            self.call_heroku_command("run", "python", "manage.py", "syncdb")
-            self.call_heroku_command("run", "python", "manage.py", "migrate")
-        if (kwargs["deploy_staticfiles"] and not kwargs["deploy_app"]) or kwargs["deploy_database"]:
-            self.call_heroku_command("restart")
+            call_command("syncdb", interactive=False)
+            call_command("migrate", interactive=False)
+        # Restart the app if required.
+        if (kwargs["deploy_staticfiles"] and not kwargs["deploy_app"]):
+            self.heroku("restart")
+        # Ensure at least one web dyno will be started.
+        heroku_ps.setdefault("web", 1)
+        # Restore running dyno state.
+        self.heroku.scale(**heroku_ps)
         # Exit maintenance mode, if required.
         if kwargs["deploy_database"]:
-            self.call_heroku_command("maintenance:off")
\ No newline at end of file
+            # Disable maintenance mode.
+            self.heroku("maintenance:off")
